# WoLBodge

## Configuration
Configuration is done using environment variables.
- `WOLBODGE_ADDRESS`: The address that WoLBodge should listen on, defaults to `:3000`.
- `WOLBODGE_STORAGE_TYPE`: Storage type to pick, defaults to `ram`.
  - `ram`: Sessions are stored in RAM.
- `WOLBODGE_DEVICE_TYPE`: Device type to pick, defaults to `test`:
  - `test`: A dummy device, used for testing.
  - `libgpiod`: Uses the libgpiod commands under the hood. The gpio chip is specified using `WOLBODGE_DEVICE_GPIOCHIP`, the power button pin using `WOLBODGE_DEVICE_POWER_BUTTON_PIN` and the power LED pin using `WOLBODGE_DEVICE_POWER_LED_PIN`.

## Usage example
Usage example for a backup script that backs up to a NAS that isn't online 24/7.
```sh
#!/usr/bin/env sh

# Start a new session
session_id=$(curl -s -X POST -F "description=Daily backup" http://localhost:3000/api/session)
exit_code=$?
if [ $exit_code != 0 ]; then
    echo "Failed to create session"
    exit 1
fi

echo "Aquired session with id $session_id"

# 1. Wait for the PC to come online (using a ping-loop for example)
# 2. Do your backup here
sleep 5

# End the session after we are done using it
curl -s -X DELETE http://localhost:3000/api/session/$session_id
exit_code=$?
if [ $exit_code != 0 ]; then
    echo "Failed to delete session"
    exit 1
fi
```
